[Global]
MoveFirst=false

[Entry 0]
Name=Web Browser
Name[af]=Web Blaaier
Name[ar]=متصفح ويب
Name[az]=Veb Səyyahı
Name[bg]=Браузър
Name[bn]=ওয়েব ব্রাউজার
Name[br]=Furcher ar Gwiad
Name[bs]=WWW Preglednik
Name[ca]=Fullejador web
Name[cs]=WWW prohlížeč
Name[cy]=Porydd Gwe
Name[da]=Browser
Name[de]=Web-Browser
Name[el]=Περιηγητής Ιστού
Name[eo]=TTT-legilo
Name[es]=Navegador web
Name[et]=Veebilehitseja
Name[eu]=Web arakatzailea
Name[fa]=مرورگر وب
Name[fi]=WWW-selain
Name[fo]=Alnótsfar
Name[fr]=Navigateur web
Name[gl]=Navegador Web
Name[he]=דפדפן אינטרנט
Name[hi]=वेब ब्राउज़र
Name[hr]=Web preglednik
Name[hu]=Webböngésző
Name[is]=Vafri
Name[it]=Browser Web
Name[ja]=ウェブブラウザ
Name[ko]=웹 브라우저
Name[lo]=ເວັບບຣາວເຊີ
Name[lt]=Žiniatinklio naršyklė
Name[lv]=Web Pārlūks
Name[mk]=Прелистувач на Интернет 
Name[mn]=Веб-Хөтөч
Name[nb]=Nettleser
Name[nds]=Nettkieker
Name[nl]=Webbrowser
Name[nn]=Nettlesar
Name[nso]=Seinyakisi sa Web
Name[pa]=ਵੈਬ ਝਲਕਾਰਾ
Name[pl]=Przeglądarka WWW
Name[pt]=Navegador Web
Name[pt_BR]=Navegador Web
Name[ro]=Navigator de web
Name[ru]=Веб-браузер
Name[se]=Fierpmádatlogan
Name[sk]=Webový prehliadač
Name[sl]=Spletni brskalnik
Name[sr]=Веб претраживач
Name[sr@Latn]=Veb pretraživač
Name[ss]=Ibrawuza yeWeb 
Name[sv]=Webbläsare
Name[ta]=வலை உலாவி
Name[tg]=Тафсиргари вэб
Name[th]=เว็บบราวเซอร์
Name[tr]=Web Tarayıcı
Name[uk]=Навігатор Тенет
Name[uz]=Веб-браузер
Name[ven]=Buronza ya Webu
Name[vi]=Trình duyệt Web
Name[wa]=Betchteu waibe
Name[xh]=Umkhangeli zincwadi we Web
Name[zh_CN]=网页浏览器
Name[zh_TW]=網頁瀏覽器
Name[zu]=Umcingi we-Web
Comment=Browse the World Wide Web
Comment[ast]=Restola pola World Wide Web
Comment[de]=Im Internet surfen
Comment[es]=Navegar por internet
Comment[el]=Εξερευνήστε το διαδίκτυο
Comment[fi]=Selaa internetiä
Comment[fr]=Surfer sur le web
Comment[gl]=Navegar pola internet
Comment[nl]=Surfen op het wereldwijde web
Comment[nl_NL]=Surfen op het wereldwijde web
Comment[sr]=Крстарите интернетом
Comment[sr@latin]=Krstarite Internetom
Comment[ja_JP]=Webを閲覧します
Icon=web-browser
Exec=exo-open --launch WebBrowser
Terminal=false
StartupNotify=false

