[Global]
MoveFirst=false

[Entry 0]
Name=Mousepad
Name[am]=የአይጥ-ስጋጃ
Name[ar]=ماوس‌باد
Name[be]=Mousepad
Name[ca]=Mousepad
Name[cs]=Mousepad
Name[cy]=Mousepad
Name[da]=Mousepad
Name[de]=Mousepad
Name[dz]=མཱའུསི་གདན། 
Name[el]=Mousepad
Name[en_GB]=Mousepad
Name[eo]=Muskuseno
Name[es]=Mousepad
Name[et]=Hoiatus, olete root kasutaja õigustes ja võite oma süsteemi kahjustada.
Name[eu]=Mousepad
Name[fi]=Mousepad
Name[fr]=Mousepad
Name[gl]=Mousepad
Name[he]=Mousepad
Name[hu]=Mousepad
Name[id]=Mousepad
Name[it]=Mousepad
Name[ja]=マウスパッド
Name[ko]=마우스패드
Name[ku]=Mousepad
Name[lt]=Mousepad
Name[lv]=Pelespaliknis
Name[mk]=Mousepad
Name[nb]=Mousepad
Name[nl]=Muispad
Name[pa]=ਮਾਊਂਸਪੈਡ
Name[pl]=Mousepad
Name[pt_BR]=Mousepad
Name[pt_PT]=Mousepad
Name[ru]=Mousepad
Name[si]=මවුස්පෑඩ්
Name[sk]=Mousepad
Name[sl]=Mousepad
Name[sq]=Mousepad
Name[sv]=Mousepad
Name[tr]=Mouse altlığı
Name[uk]=Mousepad
Name[ur]=ماؤس پیڈ
Name[zh_CN]=Mousepad
Name[zh_TW]=Mousepad
Comment=Simple text editor
Comment[am]=ቀላል የጽሑፍ ማረሚያ
Comment[ar]=محرر نصوص بسيط
Comment[be]=Просты тэкставы рэдактар
Comment[ca]=Editor de text simple
Comment[cs]=Jednoduchý textový editor
Comment[cy]=Golygydd testun syml
Comment[da]=Simpel tekstbehandler
Comment[de]=Einfacher Texteditor
Comment[dz]=ཚིག་ཡིག་འཇམ་སམ་ཞུན་དག་པ།
Comment[el]=Απλός επεξεργαστής κειμένου
Comment[en_GB]=Simple text editor
Comment[eo]=Simpla tekstomodifilo
Comment[es]=Editor de texto simple
Comment[et]=Lihtne tekstitoimetaja
Comment[eu]=Testu editore soila
Comment[fi]=Yksinkertainen tekstieditori
Comment[fr]=Un éditeur de texte simple
Comment[gl]=Editor de texto sinxelo
Comment[he]=עורך טקסט פשוט
Comment[hu]=Egyszerű szövegszerkesztő
Comment[id]=Penyunting teks sederhana
Comment[it]=Semplice editor di testo
Comment[ja]=シンプルなテキストエディタ
Comment[ko]=단순한 문서 편집기
Comment[ku]=Edîtoreke nivîsê ya hesan
Comment[lt]=Paprastas teksto redaktorius
Comment[lv]=Vienkāršs teksta redaktors
Comment[mk]=Едноставен уредувач на текст
Comment[nb]=Enkel tekstredigerer
Comment[nl]=Simpele tekstverwerker
Comment[pa]=ਸਧਾਰਨ ਟੈਕਸਟ ਐਡੀਟਰ
Comment[pl]=Prosty edytor tekstu
Comment[pt_BR]=Editor de texto simples
Comment[pt_PT]=Editor de texto simples
Comment[ru]=Простой текстовый редактор
Comment[si]=සරල පෙළ සකසනය
Comment[sk]=Jednoduchý textový editor
Comment[sl]=Preprost urejevalnik besedil
Comment[sq]=Përpunues i thjeshtë tekstesh
Comment[sv]=Enkel textredigerare
Comment[ta]=எளிமையான உரை பதிப்பான்
Comment[tr]=Basit metin editörü
Comment[uk]=Простий текстовий редактор
Comment[ur]=سادہ ٹیکسٹ ایڈیٹر
Comment[zh_CN]=简易文字编辑器
Comment[zh_TW]=簡易文字編輯器
Icon=accessories-text-editor
Exec=mousepad
Terminal=false
StartupNotify=true

