[Global]
MoveFirst=false

[Entry 0]
Name=Terminal
Name[ar]=طرفية
Name[ast]=Terminal
Name[be]=Тэрмінал
Name[ca]=Terminal
Name[cs]=Terminal
Name[da]=Terminal
Name[de]=Terminal
Name[dz]=ཊར་མི་ནཱལ།
Name[el]=Τερματικό
Name[en_GB]=Terminal
Name[eo]=Terminalo
Name[es]=Terminal
Name[et]=Terminal
Name[eu]=Terminala
Name[fi]=Pääte
Name[fr]=Terminal
Name[gl]=Terminal
Name[he]=מסוף
Name[hu]=Terminál
Name[id]=Terminal
Name[it]=Terminale
Name[ja]=Terminal
Name[kk]=Терминал
Name[ko]=터미널
Name[ku]=Termînal
Name[lv]=Terminālis
Name[nb]=Terminal
Name[nl]=Terminal
Name[pa]=ਟਰਮੀਨਲ
Name[pl]=Terminal
Name[pt]=Terminal
Name[pt_BR]=Terminal
Name[ro]=Terminal
Name[ru]=Terminal
Name[sk]=Terminál
Name[sq]=Terminal
Name[sv]=Terminal
Name[tr]=Uçbirim
Name[uk]=Термінал
Name[ur]=ٹرمنل
Name[ur_PK]=ٹرمنل
Name[vi]=Terminal
Name[zh_CN]=Xfce 终端
Name[zh_TW]=終端機
Comment=Terminal Emulator
Comment[ar]=محاكي طرفية
Comment[ast]=Emulador de terminal
Comment[be]=Эмулятар тэрмінала
Comment[ca]=Emulador de terminal
Comment[cs]=Emulátor terminálu
Comment[da]=Terminal Emulator
Comment[de]=Terminal-Programm
Comment[dz]=ཊར་མི་ནཱལ་ནུས་འཕྲུལ།
Comment[el]=Προσομοίωση τερματικού
Comment[en_GB]=Terminal Emulator
Comment[eo]=Terminala Simulilo
Comment[es]=Emulador de terminal
Comment[et]=Terminaliemulaator
Comment[eu]=Terminal emuladorea
Comment[fi]=Pääte-emulaattori
Comment[fr]=Émulateur de terminal
Comment[gl]=Emulador de Terminal
Comment[he]=מדמה מסוף
Comment[hu]=Terminálemulátor
Comment[id]=Emulator Terminal
Comment[ja]=ターミナルエミュレータ
Comment[kk]=Терминал эмуляторы
Comment[ko]=터미널 에뮬레이터
Comment[ku]=Emûlatorê Termînalê
Comment[lv]=Termināļa emulators
Comment[nb]=Teminalemulator
Comment[nl]=Terminal-emulatieprogramma
Comment[pa]=ਟਰਮੀਨਲ ਈਮੂਲੇਟਰ
Comment[pl]=Emulator terminala
Comment[pt]=Emulador de Terminal
Comment[pt_BR]=Emulador de Terminal
Comment[ro]=Emulator de terminal
Comment[ru]=Эмулятор терминала
Comment[sk]=Terminál Emulátor
Comment[sq]=Emulues Terminali
Comment[sv]=Terminalemulator
Comment[tr]=Uçbirim Öykünücüsü
Comment[uk]=Емулятор терміналу
Comment[ur]=ٹرمنل ایمولیٹر
Comment[ur_PK]=ٹرمنل ایمولیٹر
Comment[vi]=Trình giả lập Terminal
Comment[zh_CN]=终端模拟器
Comment[zh_TW]=終端機程式
Icon=utilities-terminal
Exec=exo-open --launch TerminalEmulator
Terminal=false
StartupNotify=true
