[Global]
MoveFirst=false

[Entry 0]
Name=File Manager
Name[ar]=مدير الملفات
Name[be]=Кіраўнік файлаў
Name[ca]=Gestor de fitxers
Name[cs]=Správce souborů
Name[da]=Filhåndtering
Name[de]=Dateimanager
Name[dz]=ཡིག་སྣོད་འཛིན་སྐྱོང་པ།
Name[el]=Διαχειριστής αρχείων
Name[en_GB]=File Manager
Name[eo]=Dosier-administrilo
Name[es]=Administrador de archivos
Name[et]=Failihaldur
Name[eu]=Fitxategi kudeatzailea
Name[fi]=Tiedostonhallinta
Name[fr]=Gestionnaire de fichiers
Name[gl]=Xestor de ficheiros
Name[he]=מנהל קבצים
Name[hu]=Fájlkezelő
Name[id]=Manajer Berkas
Name[it]=Gestore di file
Name[ja]=ファイルマネージャ
Name[ko]=화일 관리자
Name[ku]=Gerinendeyê Pelan
Name[lt]=Failų tvarkyklė
Name[lv]=Failu pārvaldnieks
Name[mk]=Менаџер на датотеки
Name[nb]=Filbehandler
Name[nl]=Bestandsbeheerder
Name[nn]=Filhandsamar
Name[pa]=ਫਾਇਲ ਮੈਨੇਜਰ
Name[pl]=Menedżer plików
Name[pt]=Gestor de Ficheiros
Name[pt_BR]=Gerenciador de arquivos
Name[ro]=Administrator de fişiere
Name[ru]=Файловый менеджер
Name[sk]=Správca súborov
Name[sq]=Përgjegjës Kartelash 
Name[sv]=Filhanterare
Name[tr]=Dosya Yönetimi
Name[uk]=Файловий менеджер
Name[ur]=فائل منیجر
Name[zh_CN]=文件管理器
Name[zh_TW]=檔案管理程式
Comment=Browse the filesystem with the file manager
Comment[ar]=تصفح ملفات الجهاز بمدير الملفات
Comment[be]=Вандроўка па файлавай сыстэме з кіраўніком файлаў
Comment[ca]=Navega el sistema de fitxers amb el gestor de fitxers
Comment[cs]=Procházet systém souborů správcem souborů
Comment[da]=Gennemsøg filsystem med filhåndteringen
Comment[de]=Das Dateisystem im Dateimanager anzeigen
Comment[dz]=ཡིག་སྣོད་འཛིན་སྐྱོང་པ་དང་བཅས་ཡིག་སྣོད་རིམ་ལུགས་འདི་བརྡ་འཚོལ་འབད།
Comment[el]=Περιήγηση του συστήματος αρχείων με τον διαχειριστή αρχείων
Comment[en_GB]=Browse the filesystem with the file manager
Comment[eo]=Rigardu dosier-sistemon per dosier-administrilo
Comment[es]=Explore el sistema de archivos con el administrador de archivos
Comment[et]=Lehitseda failisüsteemi kasutades failihaldurit
Comment[eu]=Fitxategi kudeatzaileaz fitxategi sistema arakatu
Comment[fi]=Selaa tiedostojärjestelmää tiedostonhallinnassa
Comment[fr]=Parcourir le système de fichiers avec le gestionnaire de fichiers
Comment[gl]=Explora-lo sistema de ficheiros co xestor de ficheiros
Comment[he]=עיין במערכת הקבצים עם מנהל הקבצים
Comment[hu]=Fájlrendszer böngészése a fájlkezelővel
Comment[id]=Ramban sistem berkas dengan manajer berkas
Comment[it]=Esplora il file system con il gestore di file
Comment[ja]=ファイルマネージャでファイルシステムを参照します
Comment[ko]=화일 관리자로 화일시스템을 탐색합니다.
Comment[lt]=Naršyti failų sistemą su failų tvarkykle
Comment[lv]=Pārlūko failsistēmu ar failu pārvaldnieku
Comment[mk]=Пребарајте го датотечниот систем со менаџерот на датотки
Comment[nb]=Utforsk filsystemet med filbehandleren
Comment[nl]=Met de bestandsbeheerder door het bestandssysteem bladeren
Comment[nn]=Bla gjennom filsystemet med filhandsamaren
Comment[pa]=ਫਾਇਲ ਮੈਨੇਜਰ ਨਾਲ ਫਾਇਲ ਸਿਸਟਮ ਨਾਲ ਬਰਾਊਜ਼ ਕਰੋ
Comment[pl]=Przegląda system plików za pomocą menedżera plików
Comment[pt]=Navegar o sistema de ficheiros com o gestor de ficheiros
Comment[pt_BR]=Navegar o sistema de arquivos com o gerenciador de arquivos
Comment[ro]=Navigare în sistemul de fişiere cu administratorul de fişiere
Comment[ru]=Просмотр файловой системы с помощью файлового менеджера
Comment[sk]=Prehliada súborový systém pomocou správcu súborov
Comment[sq]=Shfletoni sistemin e kartelave me përgjegjësin e kartelave
Comment[sv]=Bläddra i filsystemet med filhanteraren
Comment[tr]=Dosya yöneticisi ile gezin
Comment[uk]=Перегляд файлової системи менеджером файлів
Comment[ur]=فائل سسٹم کو فائل منیجر سے دیکھیں
Comment[zh_CN]=使用文件管理器浏览文件系统
Comment[zh_TW]=使用檔案管理程式瀏覽檔案系統
Icon=Thunar
Exec=thunar
Terminal=false
StartupNotify=true

